from setuptools import setup, find_packages

setup(
    name='clean_html_for_llm',
    version='1.0.1',
    description='A library for cleaning HTML content by removing specified tags and attributes.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/yourusername/clean_html',
    author='Your Name',
    author_email='your.email@example.com',
    license='MIT',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords='html cleaning',
    python_requires='>=3.7',
)



# clean_html/clean_html.py

import re

def clean_html_for_llm(html_to_clean, tags_to_remove=['style', 'svg', 'script'], attributes_to_keep=['id', 'href']):
    for tag in tags_to_remove:
        html_to_clean = re.sub(rf'<{tag}[^>]*>.*?</{tag}>', '', html_to_clean, flags=re.DOTALL)

    attributes_to_keep = '|'.join(attributes_to_keep)
    pattern = rf'\b(?!({attributes_to_keep})\b)\w+(?:-\w+)?\s*=\s*["\'][^"\']*["\']'
    cleaned_html = re.sub(pattern, '', html_to_clean)
    return cleaned_html
